# Superdesk Authentication Server

This server is used for authentication of third party clients using the production API.

The documentation is available in `/docs` directory, or can be checked at https://superdesk.readthedocs.org/.
